@@ -53,7 +53,29 @@ var group__aom__encoder =
       [ "mi_col", "structaom__partition__features.html#aed1b95e9c03152afc09f5bf181cb43f2", null ],
       [ "frame_width", "structaom__partition__features.html#a67d6bcec5129ee4685c702fb68ceea4f", null ],
       [ "frame_height", "structaom__partition__features.html#ad4f1272c0b5afaedec168eabdfbfa0c5", null ],
-      [ "block_size", "structaom__partition__features.html#a8051104747244a265e72d6f0644374df", null ]
+      [ "block_size", "structaom__partition__features.html#a8051104747244a265e72d6f0644374df", null ],
+      [ "valid_partition_types", "structaom__partition__features.html#afc57251e936f7cf74e842868d778c1ec", null ],
+      [ "update_type", "structaom__partition__features.html#a6e3435a7972fafe3c383da042cf96a77", null ],
+      [ "qindex", "structaom__partition__features.html#af8688065c0baf3ae4e7bf2c8f20861c4", null ],
+      [ "rdmult", "structaom__partition__features.html#ad695bea0d6a1659abd9a9b942ff85227", null ],
+      [ "pyramid_level", "structaom__partition__features.html#a8838d71ea72338dd142f0e433642d065", null ],
+      [ "has_above_block", "structaom__partition__features.html#a54897d3bdfef80a02c16fbcb76736485", null ],
+      [ "above_block_width", "structaom__partition__features.html#a86525024ea9f24ecf0bf31963a345fba", null ],
+      [ "above_block_height", "structaom__partition__features.html#a0a5e404813f93f836f012e60220b7c68", null ],
+      [ "has_left_block", "structaom__partition__features.html#aedbaf4a1e7751540c15b001a972359cf", null ],
+      [ "left_block_width", "structaom__partition__features.html#a79cfe2a0e3e0c15e73b5ede49a5d5f96", null ],
+      [ "left_block_height", "structaom__partition__features.html#a23af3dc77a4770dd39e045c633faf65a", null ],
+      [ "block_sse", "structaom__partition__features.html#a4b08b7405c4ba9ffedc45a30c694a964", null ],
+      [ "block_var", "structaom__partition__features.html#a31fa147e2c5387f2606c03292b85a06f", null ],
+      [ "sub_block_sse", "structaom__partition__features.html#a05dea217fcf06d906addb841d95acd98", null ],
+      [ "sub_block_var", "structaom__partition__features.html#aa7058c97bb885a6ee60c6104cb239230", null ],
+      [ "horz_block_sse", "structaom__partition__features.html#ad35552f6487fd2c82868aae20ac4e67c", null ],
+      [ "horz_block_var", "structaom__partition__features.html#a47c3ae1ced8ca3af066f93ba9565b95e", null ],
+      [ "vert_block_sse", "structaom__partition__features.html#ab1bb33100eaf6a2a77cc4e1a754eb15b", null ],
+      [ "vert_block_var", "structaom__partition__features.html#a34efa7b3edf1a5b9babf0a9c1a74e53c", null ],
+      [ "tpl_intra_cost", "structaom__partition__features.html#ab65f3261f8f6a43dfb492c43e2d0afbf", null ],
+      [ "tpl_inter_cost", "structaom__partition__features.html#a5d79662e727a19d1111c7d9b030f2d97", null ],
+      [ "tpl_mc_dep_cost", "structaom__partition__features.html#a07ddce9d308964422596892e8183e04f", null ]
     ] ],
     [ "aom_partition_decision", "structaom__partition__decision.html", [
       [ "is_final_decision", "structaom__partition__decision.html#a0382eea62fc1c2d512f39204975c2e4a", null ],
@@ -323,7 +345,10 @@ var group__aom__encoder =
       [ "AV1E_SET_EXTERNAL_PARTITION", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ad041aa24f16d1d35c59ccbe4ff8ba420", null ],
       [ "AV1E_SET_ENABLE_DIRECTIONAL_INTRA", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a54ad2c50072ecedbbcbe75df577afabd", null ],
       [ "AV1E_SET_ENABLE_TX_SIZE_SEARCH", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5af9928b5094d367d21363784ddab11139", null ],
-      [ "AV1E_SET_SVC_REF_FRAME_COMP_PRED", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a3bf579936cd7dc5e0a35e10e40a96ce9", null ]
+      [ "AV1E_SET_SVC_REF_FRAME_COMP_PRED", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a3bf579936cd7dc5e0a35e10e40a96ce9", null ],
+      [ "AV1E_SET_DELTAQ_STRENGTH", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5abd4ce26a7a8883f057e217c2a7fa86a2", null ],
+      [ "AV1E_SET_LOOPFILTER_CONTROL", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ac4c69bc7114841f8e57d4ea75dc147fd", null ],
+      [ "AOME_GET_LOOPFILTER_LEVEL", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a72c1d1e8be8ce0dd3f9b95751ec73acd", null ]
     ] ],
     [ "aom_scaling_mode_1d", "group__aom__encoder.html#ga2a1791d26fca39303154f0f9ece3e295", null ],
     [ "aom_tune_content", "group__aom__encoder.html#ga801f5eb2cb93da19a2f347ae7a44166a", null ],
